"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Cache {
    /**
     * Constructor sets empty vlaues and sets config expiration
     * @param cacheExpiration configuration expiration to create expires value
     */
    constructor(cacheExpiration) {
        this.store = {};
        this.cacheExpiration = cacheExpiration;
        this.expires = 0;
        this.etag = '';
        this.versionId = '';
    }
    /**
     * Sets data as a local value and creates expires date
     * @param data Payload of the data to store locally
     */
    set(data, etag, versionId) {
        this.store = data;
        this.expires = new Date().getTime() + this.cacheExpiration;
        this.etag = etag ? etag : '';
        this.versionId = versionId ? versionId : '';
    }
    /**
     * Gets data that is stored in memory
     * @returns locally stored data
     */
    get() {
        return this.store;
    }
    /**
     * Gets etag from data that is stored in memory
     * @returns etag of locally stored data
     */
    getEtag() {
        return this.etag;
    }
    /**
     * Checks if there is a valid cache
     * @returns true if cache is valid, false if its not
     */
    exists() {
        if (this.store && this.expires > new Date().getTime()) {
            // Checks if there is a stored object, and that has not expired yet
            return true;
        }
        else {
            // Sets store to default value
            this.clear();
            return false;
        }
    }
    /**
     * Clears local cache
     */
    clear() {
        this.store = {};
        this.expires = 0;
        this.etag = '';
    }
}
exports.Cache = Cache;
//# sourceMappingURL=cache.js.map