"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const S3 = require("aws-sdk/clients/s3");
class CloudStorage {
    constructor(config) {
        this.config = config;
        this.client = new S3(config.storage);
    }
    static init(config) {
        return new CloudStorage(config);
    }
    head(path) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let params = {
                    Bucket: this.config.database,
                    Key: path
                };
                let data = yield this.client.headObject(params).promise();
                return data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    set(value, path, metadata) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let params = {
                    Body: JSON.stringify(value),
                    Bucket: this.config.database,
                    Key: path,
                    Metadata: metadata
                };
                let data = yield this.client.putObject(params).promise();
                return data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    get(path) {
        return __awaiter(this, void 0, void 0, function* () {
            let params = {
                Bucket: this.config.database,
                Key: path
            };
            let data;
            try {
                data = yield this.client.getObject(params).promise();
                data.Body = JSON.parse(data.Body.toString('utf8'));
                // if (data.Body && data.Body.byteLength > 1) {
                //   data.Body = JSON.parse(data.Body.toString('utf8'))
                // }
                return data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    remove(path) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                let params = {
                    Bucket: this.config.database,
                    Key: path
                };
                let data = yield this.client.deleteObject(params).promise();
                return data;
            }
            catch (err) {
                throw err;
            }
        });
    }
    copy(path, ETag, metadata) {
        return __awaiter(this, void 0, void 0, function* () {
            let params = {
                Bucket: this.config.database,
                Key: path,
                CopySource: this.config.database + '/' + path,
                CopySourceIfMatch: ETag,
                MetadataDirective: 'REPLACE',
                Metadata: metadata
            };
            try {
                let data = yield this.client.copyObject(params).promise();
                return data;
            }
            catch (err) {
                throw err;
            }
        });
    }
}
exports.CloudStorage = CloudStorage;
//# sourceMappingURL=cloud.js.map