"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Builds a document url out of the array of path item
 * @param path an array of the path, to build final url
 * @returns string of the final path with extension of the document
 */
exports.documentPath = (path) => {
    let pathArray = path.map((item, index) => {
        if (path.length === index + 1) {
            // This is the last item
            if (item.type === 'document') {
                return item.key + '.json';
            }
            else {
                // if (item.type === 'collection') return item.key + '.json'
                return item.key;
            }
        }
        else {
            // not the last item
            return item.key;
        }
    });
    return pathArray.join('/');
};
exports.documentPathKey = (path) => {
    let lastItem = path[path.length - 1];
    if (lastItem.type === 'document') {
        return lastItem.key;
    }
    else {
        throw new Error('last Item in path is not a document');
    }
};
exports.checkValidObject = obj => {
    if (typeof obj === 'object' &&
        obj instanceof Object &&
        !(obj instanceof Array)) {
        return true;
    }
    else {
        throw new Error('Not a valid object');
    }
};
/**
 * Check if key that is used for document or collection is reserved
 * @param keyword to check
 * @returns true if its a reserved key
 */
function reservedKey(keyword) {
    const reservedKeyWords = {
        _meta: true,
        collection: true,
        doc: true,
        indices: true
    };
    if (reservedKeyWords[keyword]) {
        return true;
    }
    else {
        return false;
    }
}
exports.reservedKey = reservedKey;
/**
 * Creates a random uuid
 * @returns an uuid
 */
function uuid() {
    return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, c => {
        const r = (Math.random() * 16) | 0;
        const v = c === 'x' ? r : (r & 0x3) | 0x8;
        return v.toString(16);
    });
}
exports.uuid = uuid;
//# sourceMappingURL=utils.js.map