import { Payload, ICache } from '../types';
export declare class Cache implements ICache {
    /** Data that is stored in memory */
    store: Payload;
    /** Configuration on how long to keep in memory */
    cacheExpiration: number;
    /** Date when cache expires */
    expires: number;
    /** ETag of the object cached */
    etag: string;
    /** Document version id if versioning is enabled */
    versionId: string;
    /**
     * Constructor sets empty vlaues and sets config expiration
     * @param cacheExpiration configuration expiration to create expires value
     */
    constructor(cacheExpiration: number);
    /**
     * Sets data as a local value and creates expires date
     * @param data Payload of the data to store locally
     */
    set(data: Payload, etag?: string, versionId?: string): void;
    /**
     * Gets data that is stored in memory
     * @returns locally stored data
     */
    get(): Payload;
    /**
     * Gets etag from data that is stored in memory
     * @returns etag of locally stored data
     */
    getEtag(): string;
    /**
     * Checks if there is a valid cache
     * @returns true if cache is valid, false if its not
     */
    exists(): boolean;
    /**
     * Clears local cache
     */
    clear(): void;
}
